@@ -1,4 +1,4 @@
-# $Id: crt.py 1226 2015-01-25 05:43:36Z mwall $
+# $Id: crt.py 1347 2015-08-02 14:48:46Z tkeffer $
 # Copyright 2013 Matthew Wall
 """Emit loop data to file in Cumulus realtime format.
    http://wiki.sandaysoft.com/a/Realtime.txt
@@ -47,7 +47,7 @@ import weeutil.weeutil
 import weeutil.Sun
 from weewx.engine import StdService
 
-VERSION = "0.12"
+VERSION = "0.13"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -297,7 +297,7 @@ def calcMaxRad(alm, altitude_m):
         rm = math.pow((288-0.0065*rs_z)/288,5.256)/(sinal+0.15*math.pow(a0+3.885,-1.253))
         rs_toa = rs_r0 * sinal / (rs_R * rs_R)
         return rs_toa * math.pow(rs_atc, rm)
-    except Exception, e:
+    except ValueError, e:
         logdbg("cannot calculate max solar radiation: %s" % e)
         return 0
 
@@ -356,7 +356,7 @@ class CumulusRealTime(StdService):
         d = config_dict.get('CumulusRealTime', {})
         self.filename = d.get('filename', '/var/tmp/realtime.txt')
         self.datesep = d.get('date_separator', '/')
-        self.binding = d.get('binding', 'loop')
+        binding = d.get('binding', 'loop').lower()
         us = None
         us_label = d.get('unit_system', None)
         if us_label is not None:
@@ -367,12 +367,12 @@ class CumulusRealTime(StdService):
                 logerr("unknown unit_system %s" % us_label)
         self.unit_system = us
 
-        if self.binding == 'loop':
+        if binding == 'loop':
             self.bind(weewx.NEW_LOOP_PACKET, self.handle_new_loop)
         else:
             self.bind(weewx.NEW_ARCHIVE_RECORD, self.handle_new_archive)
 
-        loginf("binding is %s" % self.binding)
+        loginf("binding is %s" % binding)
         loginf("output goes to %s" % self.filename)
 
     def handle_new_loop(self, event):
@@ -387,7 +387,9 @@ class CumulusRealTime(StdService):
             data = self.calculate(event_data, dbm)
             self.write_data(data)
         except Exception, e:
+            logdbg("crt: Exception while handling data: %s" % e)
             weeutil.weeutil.log_traceback('crt: **** ')
+            raise
 
     def write_data(self, data):
         with open(self.filename, 'w') as f:
